@@ -98,7 +98,12 @@ BEGIN {
 		      SFTP_ERR_LOCAL_SYMLINK_FAILED => 34,
 		      SFTP_ERR_REMOTE_BAD_OBJECT => 35,
 		      SFTP_ERR_REMOTE_ACCESING_CLOSED_FILE => 36,
-		      SFTP_ERR_CONNECTION_BROKEN => 37 );
+		      SFTP_ERR_CONNECTION_BROKEN => 37,
+		      SFTP_ERR_LOCAL_GENERIC_ERROR => 38,
+		      SFTP_ERR_LOCAL_READLINK_FAILED => 39,
+		      SFTP_ERR_LOCAL_BAD_PATH => 40,
+		      SFTP_ERR_LOCAL_BAD_OBJECT => 41,
+		      SFTP_ERR_REMOTE_ALREADY_EXISTS => 42 );
 
     for my $key (keys %constants) {
 	no strict 'refs';
